@@ -1,10 +1,10 @@
-/* $Id: strformat.cpp 124929 2018-09-09 13:17:21Z bird $ */
+/* $Id: strformat.cpp 127855 2019-01-01 01:45:53Z bird $ */
 /** @file
  * IPRT - String Formatter.
  */
 
 /*
- * Copyright (C) 2006-2017 Oracle Corporation
+ * Copyright (C) 2006-2019 Oracle Corporation
  *
  * This file is part of VirtualBox Open Source Edition (OSE), as
  * available from http://www.virtualbox.org. This file is free software;
@@ -35,8 +35,9 @@
 #include <iprt/assert.h>
 #ifdef IN_RING3
 # include <iprt/alloc.h>
-# include <iprt/err.h>
+# include <iprt/errcore.h>
 # include <iprt/uni.h>
+# include <iprt/utf16.h>
 #endif
 #include <iprt/ctype.h>
 #include <iprt/string.h>
