@@ -1,4 +1,4 @@
-/* $Id: VBoxNetAdp-linux.c 127855 2019-01-01 01:45:53Z bird $ */
+/* $Id: VBoxNetAdp-linux.c 129718 2019-04-01 10:39:12Z bird $ */
 /** @file
  * VBoxNetAdp - Virtual Network Adapter Driver (Host), Linux Specific Code.
  */
@@ -70,8 +70,8 @@
 /*********************************************************************************************************************************
 *   Internal Functions                                                                                                           *
 *********************************************************************************************************************************/
-static int  VBoxNetAdpLinuxInit(void);
-static void VBoxNetAdpLinuxUnload(void);
+static int  __init VBoxNetAdpLinuxInit(void);
+static void __exit VBoxNetAdpLinuxUnload(void);
 
 static int VBoxNetAdpLinuxOpen(struct inode *pInode, struct file *pFilp);
 static int VBoxNetAdpLinuxClose(struct inode *pInode, struct file *pFilp);
@@ -182,7 +182,7 @@ static int vboxNetAdpLinuxXmit(struct sk_buff *pSkb, struct net_device *pNetDev)
     return 0;
 }
 
-struct net_device_stats *vboxNetAdpLinuxGetStats(struct net_device *pNetDev)
+static struct net_device_stats *vboxNetAdpLinuxGetStats(struct net_device *pNetDev)
 {
     PVBOXNETADPPRIV pPriv = netdev_priv(pNetDev);
     return &pPriv->Stats;
