@@ -1,10 +1,10 @@
-/* $Id: power-r0drv.h 118412 2017-10-17 14:26:02Z bird $ */
+/* $Id: power-r0drv.h 127888 2019-01-01 06:31:29Z bird $ */
 /** @file
  * IPRT - Power Management, Ring-0 Driver, Internal Header.
  */
 
 /*
- * Copyright (C) 2008-2017 Oracle Corporation
+ * Copyright (C) 2008-2019 Oracle Corporation
  *
  * This file is part of VirtualBox Open Source Edition (OSE), as
  * available from http://www.virtualbox.org. This file is free software;
@@ -24,8 +24,11 @@
  * terms and conditions of either the GPL or the CDDL or both.
  */
 
-#ifndef ___r0drv_powermgt_r0drv_h
-#define ___r0drv_powermgt_r0drv_h
+#ifndef IPRT_INCLUDED_SRC_r0drv_power_r0drv_h
+#define IPRT_INCLUDED_SRC_r0drv_power_r0drv_h
+#ifndef RT_WITHOUT_PRAGMA_ONCE
+# pragma once
+#endif
 
 #include <iprt/power.h>
 
@@ -37,5 +40,5 @@ DECLHIDDEN(void) rtR0PowerNotificationTerm(void);
 
 RT_C_DECLS_END
 
-#endif
+#endif /* !IPRT_INCLUDED_SRC_r0drv_power_r0drv_h */
 
